﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace ECUSimulator
{
    public partial class Form1 : Form
    {
        private int _normal_packets_sent;
        public static int MAX_NORMAL_PACKETS = 10;
        private StreamWriter _LogFile;


        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            serialPort1.PortName = global::ECUSimulator.Properties.Settings.Default.SerialPort;
            serialPort1.BaudRate = global::ECUSimulator.Properties.Settings.Default.Baudrate;
            try
            {
                serialPort1.Open();
                _LogFile = new StreamWriter(Path.Combine(
                    global::ECUSimulator.Properties.Settings.Default.LogPath,
                    "PilotDisplayLog.txt"), true);

                _normal_packets_sent = 0;
                trackBarRPM.Enabled = true;
                trackBarEDT.Enabled = true;
                btnStartStop.Enabled = true;



            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }

        public void SendNormalDataSet()
        {
            byte[] packet = new byte[] { 0xFF, 0, 0, 0, 0, 0 };
            if (serialPort1.IsOpen)
            {
                if (cbStarting.Checked) packet[1] = 0x10;
                else if (cbIdle.Checked) packet[1] = 0x40;
                else packet[1] = 1 << 5 | 1 << 2; //Started up

                packet[2] = (byte)trackBarRPM.Value;
                packet[3] = (byte)trackBarEDT.Value;
                serialPort1.Write(packet, 0, packet.Length);
                //_LogFile.WriteLine("APP: [N]->D");
                _LogFile.WriteLine(string.Format("APP: RPM={0}", packet[2]));
                _LogFile.Flush();
            }
        }

        public void SendAlternateDataSet()
        {
            byte[] packet = new byte[] { 0xFF, 0, 0, 0, 0, 0 };

            if (serialPort1.IsOpen)
            {
                if (motorTypeRadioBtn.Checked) packet[1] = 1 << 3; //Mercury
                else packet[1] = 1 << 4; //Pegasus

                serialPort1.Write(packet, 0, packet.Length);
                //_LogFile.WriteLine("APP: [A]->D");
                //_LogFile.Flush();
            }
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            if (serialPort1.IsOpen)
            {
                if (_normal_packets_sent >= MAX_NORMAL_PACKETS)
                {
                    _normal_packets_sent = 0;
                    SendAlternateDataSet();
                }
                else
                {
                    _normal_packets_sent++;
                    SendNormalDataSet();
                }
            }
        }

        private void trackBarRPM_Scroll(object sender, EventArgs e)
        {

        }

        private void trackBar1_Scroll(object sender, EventArgs e)
        {

        }

        private void motorTypeRadioBtn_CheckedChanged(object sender, EventArgs e)
        {

        }

        private void btnStartStop_Click(object sender, EventArgs e)
        {
            if (timer1.Enabled)
            {
                btnStartStop.Text = "Start";
                timer1.Enabled = false;
            }
            else
            {
                btnStartStop.Text = "Stop";
                timer1.Enabled = true;
            }
        }

        private void serialPort1_DataReceived(object sender, System.IO.Ports.SerialDataReceivedEventArgs e)
        {
            _LogFile.Write(serialPort1.ReadExisting());
            _LogFile.Flush();
        }
    }
}
